@@ -11,8 +11,8 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '1.10'
-Build = '1'
+Version = '1.11'
+Build = '2'
 
 import sys
 import os
@@ -243,13 +243,13 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        '''Opens an xterm window that sends deauthentication packets.'''
        
        # print "deauthenticate options: ", bssid, essid
-       os.system('osso-xterm -e "sudo %s/%s deauthenticate %s %s" &' % (pathMain, helperScript, bssid, essid))
+       os.system('osso-xterm -e "sudo %s/%s deauthenticate %s \"%s\" " &' % (pathMain, helperScript, bssid, essid))
 
     def executeAuthenticate(self):
        '''Opens an xterm window that sends authentication packets.'''
        
        # print "authenticate options: ", essid, bssid, myMAC
-       os.system('osso-xterm -e "sudo %s/%s authenticate %s %s %s" &' % (pathMain, helperScript, bssid, myMAC, essid))
+       os.system('osso-xterm -e "sudo %s/%s authenticate %s %s \"%s\" " &' % (pathMain, helperScript, bssid, myMAC, essid))
 
     def executeInjection(self):
        '''Opens an xterm window that sends injection packets.'''
@@ -301,7 +301,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        elif kernelVersion == '2.6.28.10-power48':
           pass
        else: 
-          message = 'WARNING: The system did not find a compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
+          message = 'WARNING: The system did not find a known compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
           showMessage(message)
     
     def getDriversState(self):
@@ -383,10 +383,10 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        '''Get the MAC address defined on the device'''
 
        if self.ui.enableMonitor.isEnabled():
-          #interface is in Managed mode
+          ##interface is in Managed mode
           macList = os.popen('sudo %s/%s getMACmanaged' %(pathMain, helperScript)).read()
        else:
-          #interface is in Monitor mode 
+          ##interface is in Monitor mode 
           macList = os.popen('sudo %s/%s getMACmonitor' %(pathMain, helperScript)).read()
        
        myMAC = macList[0:17]
@@ -431,7 +431,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
     def setConnectionBehaviour(self):
        '''Set new data connection behaviour.'''
 
-       ## Available options: [WLAN_INFRA], [GPRS], [*] <=='any', [] <=='ask'
+       ##Available options: [WLAN_INFRA], [GPRS], [*] <=='any', [] <=='ask'
        if self.ui.ASK.isChecked():
            String = ''
        elif self.ui.WLAN.isChecked():
@@ -441,7 +441,7 @@ class clevenConfigureDrivers(QtGui.QDialog): # Complete
        elif self.ui.ANY.isChecked():
            String = '*'
           
-       ## Set requested setting for "Connect automatically" 
+       ##Set user requested value for the "Connect automatically" option 
        os.system('gconftool-2 -s --type list --list-type string /system/osso/connectivity/network_type/auto_connect [%s]' % String)
 
 class clevenSelectDictionary(QtGui.QDialog): # Complete
@@ -480,7 +480,7 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        QtCore.QObject.connect(self.ui.actionEnableDeleteOptions, QtCore.SIGNAL('triggered()'), self.enableDeleteOptions)
        QtCore.QObject.connect(self.ui.actionDisableDeleteOptions, QtCore.SIGNAL('triggered()'), self.disableDeleteOptions)
        
-       # Decryption
+       ##Decryption
        QtCore.QObject.connect(self.ui.decryptButton, QtCore.SIGNAL('clicked()'), self.decryptORdeleteCapturedFiles)
        QtCore.QObject.connect(self.ui.dictionaryButton, QtCore.SIGNAL('clicked()'), self.showSelectDictionaryDialog)
        QtCore.QObject.connect(self.ui.capturedList, QtCore.SIGNAL('itemSelectionChanged()'), self.enableDecryptionButtons)
@@ -557,7 +557,7 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
        self.ui.decryptButton.setEnabled(False)
        
        clist = os.listdir(pathTemp + '/' + folderCapturedData + '/' + encryption)
-       clist_clean = [line for line in clist if '.cap' in line]
+       clist_clean = [line for line in clist if (('.cap' in line) or ('ivs' in line))]
        clist_clean.sort(key=str.lower)
        self.ui.capturedList.addItems(clist_clean)
 
@@ -575,13 +575,16 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
           if self.ui.selectCommonRadio.isChecked():
              name = self.capfile.strip().partition('-')
              name = name[0]
-             cap = name+'*.cap'
+             suffix = self.capfile.strip().partition('.')
+             suffix = suffix[1]
+             if suffix == 'ivs':
+                cap = name+'*.ivs'
+             else:
+                cap = name+'*.cap'
              key = name+'-common'
           else:
              cap = self.capfile.strip()
              key = self.capfile.strip()
-          # print "cap: ", cap
-          # print "key: ", key 
           
           if self.ui.wpaRadio.isChecked():
              if myDictionary == '':
@@ -669,7 +672,7 @@ class clevenAbout(QtGui.QMainWindow): # Complete
        aboutScrollArea = QScrollArea(self)
        aboutScrollArea.setWidgetResizable(True)
        awidget = QWidget(aboutScrollArea)
-       awidget.setMinimumSize(470,1480)
+       # awidget.setMinimumSize(470,1480)
        awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
        aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
        try:
@@ -686,51 +689,19 @@ class clevenAbout(QtGui.QMainWindow): # Complete
        aboutIcon.resize(128,128)
        aboutLayout.addWidget(aboutIcon)
        
-       aboutLabel = QLabel('''<center><b>Cleven</b> 
-                               <br>version: %s
-                               <br>
-                               <br>
-                               <b>Cleven is a user interface to the 
-                               <br>AirCrack-NG console application.</b>
-                               <br>
-                               <br>Licenced under GPLv2
-                               <br>by <b>Christos Zamantzas</b> (Saturn)
-                               <br>
-                               <br>It provides the ability to easily
-                               <br>configure the injection drivers,
-                               <br>scan for surrounding stations,
-                               <br>and, using injection and
-                               <br>authentication or deauthentication, 
-                               <br>capture Identification Vector keys.
-                               <br>
-                               <br>In addition, it provides interfaces 
-                               <br>to decrypt the captured files and 
-                               <br>manage the successful attacks.
-                               <br>
-                               <br><b>DISCLAIMER:</b>
-                               <br>This program is intended for learning
-                               <br>purposes only. I do not condone hacking
-                               <br>and wouldn't be held responsible for
-                               <br>your actions. Only you would face legal
-                               <br>consequences if you used this script
-                               <br>for illegal activities.
-                               <br>
-                               <br>Additional information on the usage,
-                               <br>settings and implications can be found in
-                               <br>the wiki pages (see buttons in the end).
-                               <br>
-                               <br><b>THANKS TO:</b>
-                               <br><b>David Gnedt</b> (lxp) for the 
-                               <br>development of the bleeding-edge 
-                               <br>wlan drivers. You can support his work 
-                               <br>by donating. See here for more info: 
-                               <br>http://david.gnedt.eu/blog/wl1251/
-                               <br>
-                               <br><b>Benoit HERVIER</b> at http://khertan.net/
-                               <br>for the code used in this about window.
-                               <br>
-                               </center>''' % Version)
+       aboutLabel = QLabel('''<center><b>Cleven</b> version: %s 
+       <br><br><b>Cleven is a user interface to the aircrack-ng console application.</b> 
+       <br><br>Licenced under GPLv2 
+       <br>by <b>Christos Zamantzas</b> (Saturn) 
+       <br><br>It provides the ability to easily configure the injection drivers, scan for surrounding stations, and, using injection and authentication or deauthentication, capture the Identification Vector keys.  In addition, it provides interfaces to decrypt the captured files and manage the successful attacks.  
+       <br><br><b>DISCLAIMER:</b> This program is intended for learning purposes only. I do not condone hacking and would not be held responsible for your actions. Only you would face legal consequences if you used this application for illegal activities.  Additional information on the usage, settings and implications can be found in the wiki pages (see buttons in the end).
+       <br><br><b>THANKS TO:
+       <br></b> <b>David Gnedt</b> (lxp) for the development of the bleeding-edge wlan drivers. You can support his work by donating. See here for more info: http://david.gnedt.eu/blog/wl1251/
+       <br><b>Benoit HERVIER</b> at http://khertan.net/ for the code used in this about window. </center>''' % Version)
+       
+       aboutLabel.setWordWrap(True)       
        aboutLayout.addWidget(aboutLabel)
+       
        self.wikiButton = QPushButton('Cleven Wiki')
        self.wikiButton.clicked.connect(self.openWikiPage)
        self.issuesButton = QPushButton('Issue Tracker')
